Package 'envirotox'

Title: Envirotox Datasets
Description: The envirotox R data package provides Species Sensitivity Distribution (SSD) datasets from the Envirotox database 2.0.0 (Connors et al. 2019). The datasets are provided for assessing general patterns in SSD data and testing code. The datasets should not be used to draw any conclusions about the toxicity of the individual chemicals.
Authors: Joe Thorley [aut, cre] (ORCID: <https://orcid.org/0000-0002-7683-4592>), Rebecca Fisher [aut], Ayla Pearson [ctb] (ORCID: <https://orcid.org/0000-0001-7388-1222>)
Maintainer: Joe Thorley <[email protected]>
License: file LICENSE
Version: 0.0.0.9003
Built: 2026-06-03 21:53:57 UTC
Source: https://github.com/poissonconsulting/envirotox

Help Index


Acute Species Sensitivity Datasets

Description

Acute Species Sensitivity Datasets

Usage

envirotox_acute

Format

envirotox_acute

A data frame with 14,949 rows and 6 columns:

Chemical

Chemical name (chr)

Conc

Concentration of chemical in micrograms per litre (dbl).

Species

Species name (chr).

Group

Taxonomic group of species (chr).

Yanagihara24

Whether the dataset fits the criteria of Yanagihara et al. (2024) (flag).

Iwasaki25

Whether the dataset was included in Iwasaki et al. (2025) (flag).

https://envirotoxdatabase.org/

References

Yanagihara, M., Hiki, K., and Iwasaki, Y. 2024. Which distribution to choose for deriving a species sensitivity distribution? Implications from analysis of acute and chronic ecotoxicity data. Ecotoxicology and environmental safety 278: 116379. doi:10.1016/j.ecoenv.2024.116379.

Iwasaki, Y., and Yanagihara, M. 2025. Comparison of model-averaging and single-distribution approaches to estimating species sensitivity distributions and hazardous concentrations for 5% of species. Environmental Toxicology and Chemistry 44(3): 834–840. doi:10.1093/etojnl/vgae060.

Examples

head(envirotox_acute)

Envirotox Chemical Data

Description

Envirotox Chemical Data

Usage

envirotox_chemical

Format

envirotox_chemical

A data frame with 744 rows and 2 columns:

Chemical

Chemical name (chr)

OriginalCAS

Original Chemical Abstracts Service Registry Number (int)

https://envirotoxdatabase.org/

Examples

head(envirotox_chemical)

Chronic Species Sensitivity Datasets

Description

Chronic Species Sensitivity Datasets

Usage

envirotox_chronic

Format

envirotox_chronic

A data frame with 1,721 rows and 6 columns:

Chemical

Chemical name (chr)

Conc

Concentration of chemical in micrograms per litre (dbl).

Species

Species name (chr).

Group

Taxonomic group of species (chr).

Yanagihara24

Whether the dataset fits the criteria of Yanagihara et al. (2024) (flag).

https://envirotoxdatabase.org/

References

Yanagihara, M., Hiki, K., and Iwasaki, Y. 2024. Which distribution to choose for deriving a species sensitivity distribution? Implications from analysis of acute and chronic ecotoxicity data. Ecotoxicology and environmental safety 278: 116379. doi:10.1016/j.ecoenv.2024.116379.

Examples

head(envirotox_chronic)

Lists the datasets

Description

Lists the names of the datasets in the package.

Usage

list_datasets()

Value

A character vector of the dataset names.

Examples

list_datasets()