| Title: | Envirotox Datasets |
|---|---|
| Description: | The envirotox R data package provides Species Sensitivity Distribution (SSD) datasets from the Envirotox database 2.0.0 (Connors et al. 2019). The datasets are provided for assessing general patterns in SSD data and testing code. The datasets should not be used to draw any conclusions about the toxicity of the individual chemicals. |
| Authors: | Joe Thorley [aut, cre] (ORCID: <https://orcid.org/0000-0002-7683-4592>), Rebecca Fisher [aut], Ayla Pearson [ctb] (ORCID: <https://orcid.org/0000-0001-7388-1222>) |
| Maintainer: | Joe Thorley <[email protected]> |
| License: | file LICENSE |
| Version: | 0.0.0.9003 |
| Built: | 2026-06-03 21:53:57 UTC |
| Source: | https://github.com/poissonconsulting/envirotox |
Acute Species Sensitivity Datasets
envirotox_acuteenvirotox_acute
envirotox_acuteA data frame with 14,949 rows and 6 columns:
Chemical name (chr)
Concentration of chemical in micrograms per litre (dbl).
Species name (chr).
Taxonomic group of species (chr).
Whether the dataset fits the criteria of Yanagihara et al. (2024) (flag).
Whether the dataset was included in Iwasaki et al. (2025) (flag).
https://envirotoxdatabase.org/
Yanagihara, M., Hiki, K., and Iwasaki, Y. 2024. Which distribution to choose for deriving a species sensitivity distribution? Implications from analysis of acute and chronic ecotoxicity data. Ecotoxicology and environmental safety 278: 116379. doi:10.1016/j.ecoenv.2024.116379.
Iwasaki, Y., and Yanagihara, M. 2025. Comparison of model-averaging and single-distribution approaches to estimating species sensitivity distributions and hazardous concentrations for 5% of species. Environmental Toxicology and Chemistry 44(3): 834–840. doi:10.1093/etojnl/vgae060.
head(envirotox_acute)head(envirotox_acute)
Envirotox Chemical Data
envirotox_chemicalenvirotox_chemical
envirotox_chemicalA data frame with 744 rows and 2 columns:
Chemical name (chr)
Original Chemical Abstracts Service Registry Number (int)
https://envirotoxdatabase.org/
head(envirotox_chemical)head(envirotox_chemical)
Chronic Species Sensitivity Datasets
envirotox_chronicenvirotox_chronic
envirotox_chronicA data frame with 1,721 rows and 6 columns:
Chemical name (chr)
Concentration of chemical in micrograms per litre (dbl).
Species name (chr).
Taxonomic group of species (chr).
Whether the dataset fits the criteria of Yanagihara et al. (2024) (flag).
https://envirotoxdatabase.org/
Yanagihara, M., Hiki, K., and Iwasaki, Y. 2024. Which distribution to choose for deriving a species sensitivity distribution? Implications from analysis of acute and chronic ecotoxicity data. Ecotoxicology and environmental safety 278: 116379. doi:10.1016/j.ecoenv.2024.116379.
head(envirotox_chronic)head(envirotox_chronic)
Lists the names of the datasets in the package.
list_datasets()list_datasets()
A character vector of the dataset names.
list_datasets()list_datasets()